@@ -5,14 +5,14 @@ from os import system, remove, popen
 from os.path import exists
 from shutil import copy as copy_file
 from glob import glob
-from cogent import DNA, LoadSeqs
+from cogent import DNA, LoadSeqs, Sequence
 from cogent.util.misc import remove_files
 from cogent.core.alignment import SequenceCollection, DenseAlignment
 from cogent.align.align import make_dna_scoring_dict, global_pairwise
 from cogent.app.blast import blastn
 from cogent.app.formatdb import build_blast_db_from_seqs, \
  build_blast_db_from_fasta_path
-from cogent.app.muscle import align_unaligned_seqs as muscle_align_unaligned_seqs
+from cogent.app.muscle_v38 import align_unaligned_seqs as muscle_align_unaligned_seqs
 from cogent.app.mafft import align_unaligned_seqs as mafft_align_unaligned_seqs
 from cogent.app.clustalw import align_unaligned_seqs as clustal_align_unaligned_seqs
 from cogent.app.util import get_tmp_filename
@@ -23,12 +23,12 @@ from pynast.logger import NastLogger
 
 __author__ = "Greg Caporaso"
 __copyright__ = "Copyright 2010, The PyNAST Project"
-__credits__ = ["Greg Caporaso", "Kyle Bittinger"]
+__credits__ = ["Greg Caporaso", "Kyle Bittinger", "Jai Ram Rideout"]
 __license__ = "GPL"
-__version__ = "1.1"
+__version__ = "1.2"
 __maintainer__ = "Greg Caporaso"
 __email__ = "gregcaporaso@gmail.com"
-__status__ = "Release"
+__status__ = "Development"
 
 """ PyNAST is a complete rewrite of the NAST algorithm written in python.
  While PyNAST 1.0 strived to exactly match the results of the original 
@@ -39,9 +39,9 @@ __status__ = "Release"
  PyNAST depends on PyCogent, NumPy, Python, and uclust. The versions 
  used for development are:
  
- PyCogent 1.4.1
- NumPy 1.3.0
- Python 2.5.1
+ PyCogent 1.5.3
+ NumPy 1.5.1
+ Python 2.7.1
  uclust 1.1.579
  
 The PyNAST algorithm works as follows:
@@ -485,7 +485,7 @@ def pynast_seq(candidate_sequence, template_alignment,
     align_unaligned_seqs_f
       Function to align sequences. Must be of the form:
        align_unaligned_seqs(seqs, moltype, params=None)
-       see cogent.app.muscle.align_unaligned_seqs
+       see cogent.app.muscle_v38.align_unaligned_seqs
     """
     depreciation_warning(kwargs)
     class SingleSeqLogger(object):
@@ -543,7 +543,7 @@ def ipynast_seqs(candidate_sequences, template_alignment,
     align_unaligned_seqs_f
       Function to align sequences. Must be of the form:
        align_unaligned_seqs(seqs, moltype, params=None)
-       see cogent.app.muscle.align_unaligned_seqs
+       see cogent.app.muscle_v38.align_unaligned_seqs
     log_fp
       Optional path to log file
     logger
@@ -555,28 +555,43 @@ def ipynast_seqs(candidate_sequences, template_alignment,
     files_to_remove = []
     if type(candidate_sequences) == str:
         # filepath provided for candidate sequences
-        candidate_fasta_filepath = candidate_sequences
-    else:
-        # sequence list provided for candidate sequence -- write 
-        # the seqs to a temp file to pass to uclust
-        candidate_fasta_filepath = \
-         get_tmp_filename(prefix='pynast_candidate',suffix='.fasta')
-        candidate_fasta_f = open(candidate_fasta_filepath,'w')
-        for s in candidate_sequences:
-            candidate_fasta_f.write('>%s\n%s\n' % (s))
-        candidate_fasta_f.close()
-        files_to_remove.append(candidate_fasta_filepath)
+        candidate_sequences = MinimalFastaParser(open(candidate_sequences))
 
-    # degap the template alignment for the sequence searching step
-    if type(template_alignment) == str:
-        # template alignment provided as filepath -- load it into
-        # an Alignment object
-        template_alignment = LoadSeqs(template_alignment,moltype=DNA)
-    # degap the alignment, and write it to a temp file
+    # sequence list provided for candidate sequence -- write 
+    # the seqs to a temp file to pass to uclust. This is done in all
+    # cases to convert the sequences to uppercase in case they're not already.
+    # The bad handling of upper versus lower-cased sequences is a uclust issue.
+    candidate_fasta_filepath = \
+     get_tmp_filename(prefix='pynast_candidate',suffix='.fasta')
+    candidate_fasta_f = open(candidate_fasta_filepath,'w')
+    for seq_id, seq in candidate_sequences:
+        candidate_fasta_f.write('>%s\n%s\n' % (seq_id,str(seq).upper()))
+    candidate_fasta_f.close()
+    files_to_remove.append(candidate_fasta_filepath)
+
+    # degap the template alignment for the sequence searching step and
+    # write it to file
     template_fasta_filepath = \
      get_tmp_filename(prefix='pynast_template',suffix='.fasta')
     template_fasta_f = open(template_fasta_filepath,'w')
-    template_fasta_f.write(template_alignment.degap().toFasta())
+    
+    if type(template_alignment) == str:
+        # the template alignment was received as a filepath
+        try:
+            template_alignment_f = open(template_alignment)
+        except IOError:
+            raise IOError,\
+             "Cannot open specified filepath: %s" % template_alignment
+        # template alignment provided as filepath -- process it iteratively
+        # to handle potentially massive template_alignments
+        template_alignment = {}
+        for seq_id,seq in MinimalFastaParser(template_alignment_f):
+            template_alignment[seq_id] = seq
+            seq = Sequence(seq=seq,moltype=DNA)
+            template_fasta_f.write('>%s\n%s\n' % (seq_id,seq.degap()))
+    else:
+        # the template alignment was received as a filepath
+        template_fasta_f.write(template_alignment.degap().toFasta())
     template_fasta_f.close()
     files_to_remove.append(template_fasta_filepath)
          
@@ -649,8 +664,12 @@ def ipynast_seqs(candidate_sequences, template_alignment,
             candidate_seq_id = pw_aligned_candidate.Name
     
             # get the aligned template sequence from the template alignment
-            template_aligned_seq = \
-             template_alignment.getGappedSeq(template_seq_id)
+            try:
+                template_aligned_seq = \
+                 template_alignment.getGappedSeq(template_seq_id)
+            except AttributeError:
+                template_aligned_seq = \
+                 Sequence(seq=template_alignment[template_seq_id],moltype=DNA)
     
             # reintroduce the gap spacing from the template alignment
             pw_aligned_template, pw_aligned_candidate, new_gaps =\
@@ -733,7 +752,7 @@ def pynast_seqs(candidate_sequences, template_alignment, max_hits=30,
     align_unaligned_seqs_f
       Function to align sequences. Must be of the form:
        align_unaligned_seqs(seqs, moltype, params=None)
-       see cogent.app.muscle.align_unaligned_seqs
+       see cogent.app.muscle_v38.align_unaligned_seqs
     log_fp
       Optional path to log file
     logger
